@@ -12,7 +12,7 @@ from tools.config.save import save, save_session
 #
 # Exported variables (internal configuration)
 #
-version = "1.2.0"
+version = "1.3.0"
 tools_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 
 # Keys saved in the config file (mostly what we ask in 'waydroid init')
@@ -71,8 +71,8 @@ if session_defaults["pulse_runtime_path"] == "None":
 
 channels_defaults = {
     "config_path": "/usr/share/waydroid-extra/channels.cfg",
-    "system_channel": "http://ota.waydro.id/system",
-    "vendor_channel": "http://ota.waydro.id/vendor",
+    "system_channel": "https://ota.waydro.id/system",
+    "vendor_channel": "https://ota.waydro.id/vendor",
     "rom_type": "lineage",
     "system_type": "VANILLA"
 }
